==> linktocontent-5.x-1.0.tar.gz: linktocontent/tinymce_plugins/linktomenu/jscripts/nodelist.js <==
// $Id: nodelist.js,v 1.1.2.1 2007/03/01 20:21:20 stborchert Exp $

var selectedNode = null;

function _fillNodelist(results) {
  if ((results == null) || (results.menus == null) || (results.menus == false))
    return;

  for (key in results.menus) {
    if (results.menus[key].root) {
      continue;
    }
    _addNodeToList(results.menus[key]);
  }
}

function _clearNodeList() {
  $("#nodelist tbody tr").each(
    function() {
      $(this).remove();
    }
  );
}

function selectRow(row) {
  if (!row) {
    return;
  }
  $('#nodelist tbody tr').each(function() { $(this).css('background', '#ffffff'); selectedNode = null; });
  selectedNode = row;
  $(row).css('background', '#dadfe9');
}

function _addNodeToList(node){
  var tr = $("<tr></tr>").appendTo("#nodelist tbody");
  tr.hover(
    function() {
      if (selectedNode != this) {
        $(this).css('background', '#cecece');
      }
    },
    function() {
      if (selectedNode != this) {
        $(this).css('background', '#ffffff');
      }
    }
  );
  tr.click(function() {
    selectRow(this);
  });

  var td = $("<td class=\"nid\">" + node.path + "</td>").appendTo(tr);

  $("<td>" + node.title + "</td>").appendTo(tr);
}

/**
 * make the nodelist accessible by keyboard
 **/
$('.accessible').keypress(function(e) {
  switch (e.keyCode) {
    case 39:
    case 40: // move selection down
      if (selectedNode == null)
        selectedNode = $('#nodelist tbody tr').get(0);
      else
        selectedNode = $(selectedNode).next('tr').get(0);
      selectRow(selectedNode);
      break;
    case 37:
    case 38: // move selection up
      if (selectedNode == null)
        selectedNode = $('#nodelist tbody tr').get($('#nodelist tbody tr').length - 1);
      else
        selectedNode = $(selectedNode).prev('tr').get(0);
      selectRow(selectedNode);
    break;
  }
});

==> linktocontent-5.x-1.3.tar.gz: linktocontent/tinymce_plugins/linktomenu/jscripts/nodelist.js <==
// $Id: nodelist.js,v 1.1.2.2 2007/06/03 10:34:32 stborchert Exp $

var selectedNode = null;

function _fillNodelist(results) {
  if ((results == null) || (results.menus == null) || (results.menus == false))
    return;

  for (key in results.menus) {
    if (results.menus[key].root) {
      continue;
    }
    _addNodeToList(results.menus[key]);
  }
}

function _clearNodeList() {
  $('#nodelist tbody tr').each(
    function() {
      $(this).remove();
    }
  );
}

function selectRow(row) {
  if (!row) {
    return;
  }
  $('#nodelist tbody tr').each(function() { 
    $(this).css({background: '#ffffff'}); 
    selectedNode = null; 
  });
  selectedNode = row;
  $(row).css({background: '#dadfe9'});
}

function _addNodeToList(node){
  var tr = $('<tr></tr>').appendTo('#nodelist tbody');
  tr.hover(
    function() {
      if (selectedNode != this) {
        $(this).css({background: '#cecece'});
      }
    },
    function() {
      if (selectedNode != this) {
        $(this).css({background: '#ffffff'});
      }
    }
  );
  tr.click(function() {
    selectRow(this);
  });

  $('<td class="nid">' + node.path + '</td>').appendTo(tr);
  $('<td>' + node.title + '</td>').appendTo(tr);
}

/**
 * make the nodelist accessible by keyboard
 **/
$('.accessible').keypress(function(e) {
  switch (e.keyCode) {
    case 39:
    case 40: // move selection down
      if (selectedNode == null)
        selectedNode = $('#nodelist tbody tr').get(0);
      else
        selectedNode = $(selectedNode).next('tr').get(0);
      selectRow(selectedNode);
      break;
    case 37:
    case 38: // move selection up
      if (selectedNode == null)
        selectedNode = $('#nodelist tbody tr').get($('#nodelist tbody tr').length - 1);
      else
        selectedNode = $(selectedNode).prev('tr').get(0);
      selectRow(selectedNode);
    break;
  }
});
